@@ -3,24 +3,21 @@
 from ._common import (
     as_file,
     files,
-)
-
-from importlib_resources._py3 import (
     Package,
-    Resource,
-    contents,
-    is_resource,
-    open_binary,
-    open_text,
-    path,
-    read_binary,
-    read_text,
 )
-from importlib_resources.abc import ResourceReader
 
-# For compatibility. Ref #88.
-# Also requires hook-importlib_resources.py (Ref #101).
-__import__('importlib_resources.trees')
+from ._legacy import (
+    contents,
+    open_binary,
+    read_binary,
+    open_text,
+    read_text,
+    is_resource,
+    path,
+    Resource,
+)
+
+from importlib_resources.abc import ResourceReader
 
 
 __all__ = [
